@@ -1,10 +1,11 @@
 package Markdent::Dialect::Standard::BlockParser;
+BEGIN {
+  $Markdent::Dialect::Standard::BlockParser::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use Digest::SHA1 qw( sha1_hex );
 use Markdent::Event::StartDocument;
 use Markdent::Event::EndDocument;
@@ -748,7 +749,9 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Block parser for standard Markdown
+
+
 
 =pod
 
@@ -756,6 +759,10 @@ __END__
 
 Markdent::Dialect::Standard::BlockParser - Block parser for standard Markdown
 
+=head1 VERSION
+
+version 0.10
+
 =head1 DESCRIPTION
 
 This class parses blocks for the standard Markdown dialect (as defined by
@@ -786,13 +793,17 @@ See L<Markdent> for bug reporting details.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
