@@ -1,10 +1,11 @@
 package Markdent::Dialect::Theory::BlockParser;
+BEGIN {
+  $Markdent::Dialect::Theory::BlockParser::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use List::AllUtils qw( insert_after_string sum );
 use Markdent::Event::StartTable;
 use Markdent::Event::EndTable;
@@ -423,13 +424,19 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Block parser for Theory's Markdown
+
+
 
 =pod
 
 =head1 NAME
 
-Markdent::Dialect::Standard::BlockParser - Block parser for Theory's Markdown
+Markdent::Dialect::Theory::BlockParser - Block parser for Theory's Markdown
+
+=head1 VERSION
+
+version 0.10
 
 =head1 DESCRIPTION
 
@@ -458,13 +465,17 @@ See L<Markdent> for bug reporting details.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
