@@ -1,10 +1,11 @@
 package Markdent::Dialect::Theory::SpanParser;
+BEGIN {
+  $Markdent::Dialect::Theory::SpanParser::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use namespace::autoclean;
 use Moose;
 use MooseX::SemiAffordanceAccessor;
@@ -23,13 +24,19 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Span parser for Theory's Markdown
+
+
 
 =pod
 
 =head1 NAME
 
-Markdent::Dialect::Standard::SpanParser - Span parser for Theory's Markdown
+Markdent::Dialect::Theory::SpanParser - Span parser for Theory's Markdown
+
+=head1 VERSION
+
+version 0.10
 
 =head1 DESCRIPTION
 
@@ -53,13 +60,17 @@ See L<Markdent> for bug reporting details.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
