@@ -1,10 +1,11 @@
 package Markdent::Event::EndHeader;
+BEGIN {
+  $Markdent::Event::EndHeader::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use Markdent::Types qw( HeaderLevel );
 
 use namespace::autoclean;
@@ -23,7 +24,9 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: An event for the end of a header
+
+
 
 =pod
 
@@ -31,6 +34,10 @@ __END__
 
 Markdent::Event::EndHeader - An event for the end of a header
 
+=head1 VERSION
+
+version 0.10
+
 =head1 DESCRIPTION
 
 This class represents the end of a header.
@@ -53,13 +60,17 @@ See L<Markdent> for bug reporting details.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
