@@ -1,10 +1,11 @@
 package Markdent::Event::StartTableBody;
+BEGIN {
+  $Markdent::Event::StartTableBody::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use Markdent::Types qw( Str );
 
 use namespace::autoclean;
@@ -17,7 +18,9 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: An event for the start of a table body
+
+
 
 =pod
 
@@ -25,6 +28,10 @@ __END__
 
 Markdent::Event::StartTableBody - An event for the start of a table body
 
+=head1 VERSION
+
+version 0.10
+
 =head1 DESCRIPTION
 
 This class represents the start of a table body. A table can have more than
@@ -40,13 +47,17 @@ See L<Markdent> for bug reporting details.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
