@@ -1,10 +1,11 @@
 package Markdent::Handler::CaptureEvents;
+BEGIN {
+  $Markdent::Handler::CaptureEvents::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use Markdent::CapturedEvents;
 
 use namespace::autoclean;
@@ -28,7 +29,9 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Captures events for replaying later
+
+
 
 =pod
 
@@ -36,6 +39,10 @@ __END__
 
 Markdent::Handler::CaptureEvents - Captures events for replaying later
 
+=head1 VERSION
+
+version 0.10
+
 =head1 DESCRIPTION
 
 This class implements an event receiver which simply captures events using
@@ -65,13 +72,17 @@ See L<Markdent> for bug reporting details.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
