@@ -1,10 +1,11 @@
 package Markdent::Handler::HTMLFilter;
+BEGIN {
+  $Markdent::Handler::HTMLFilter::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use Markdent::CapturedEvents;
 
 use namespace::autoclean;
@@ -32,7 +33,9 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Filters out HTML events from the event stream
+
+
 
 =pod
 
@@ -40,6 +43,10 @@ __END__
 
 Markdent::Handler::HTMLFilter - Filters out HTML events from the event stream
 
+=head1 VERSION
+
+version 0.10
+
 =head1 SYNOPSIS
 
   my $html = Markdent::Handler::HTMLStream->new( ... );
@@ -73,13 +80,17 @@ See L<Markdent> for bug reporting details.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
