@@ -1,10 +1,11 @@
 package Markdent::Handler::MinimalTree;
+BEGIN {
+  $Markdent::Handler::MinimalTree::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use MooseX::Params::Validate qw( validated_list validated_hash );
 use Markdent::Types qw(
     HeaderLevel Str Bool HashRef
@@ -434,7 +435,9 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: A Markdent handler which builds a tree
+
+
 
 =pod
 
@@ -442,6 +445,10 @@ __END__
 
 Markdent::Handler::MinimalTree - A Markdent handler which builds a tree
 
+=head1 VERSION
+
+version 0.10
+
 =head1 DESCRIPTION
 
 This class implements an event receiver which in turn builds a tree using
@@ -472,13 +479,17 @@ See L<Markdent> for bug reporting details.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
