@@ -1,10 +1,11 @@
 package Markdent::Parser;
+BEGIN {
+  $Markdent::Parser::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use Class::MOP;
 use Markdent::Dialect::Standard::BlockParser;
 use Markdent::Dialect::Standard::SpanParser;
@@ -198,7 +199,9 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: A markdown parser
+
+
 
 =pod
 
@@ -206,6 +209,10 @@ __END__
 
 Markdent::Parser - A markdown parser
 
+=head1 VERSION
+
+version 0.10
+
 =head1 SYNOPSIS
 
   my $handler = Markdent::Handler::HTMLStream->new( ... );
@@ -288,13 +295,17 @@ See L<Markdent> for bug reporting details.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
