@@ -1,10 +1,11 @@
 package Markdent::Regexes;
+BEGIN {
+  $Markdent::Regexes::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use List::AllUtils qw( uniq );
 
 use base 'Exporter';
@@ -34,3 +35,28 @@ our $BlockEnd = qr/(?=(?: $EmptyLines | \z ) )/xm;
 our $HTMLComment = qr{<!--(.+?)-->}s;
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Markdent::Regexes
+
+=head1 VERSION
+
+version 0.10
+
+=head1 AUTHOR
+
+  Dave Rolsky <autarch@urth.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Dave Rolsky.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
