@@ -1,10 +1,11 @@
 package Markdent::Role::AnyParser;
+BEGIN {
+  $Markdent::Role::AnyParser::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use namespace::autoclean;
 use Moose::Role;
 
@@ -60,7 +61,9 @@ sub _debug_look_for {
 
 1;
 
-__END__
+# ABSTRACT: A role for block and span parsers
+
+
 
 =pod
 
@@ -68,6 +71,10 @@ __END__
 
 Markdent::Role::AnyParser - A role for block and span parsers
 
+=head1 VERSION
+
+version 0.10
+
 =head1 DESCRIPTION
 
 This role implements behavior shared by all types of parser.
@@ -101,13 +108,17 @@ See L<Markdent> for bug reporting details.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
