@@ -1,10 +1,11 @@
 package Markdent::Role::BalancedEvent;
+BEGIN {
+  $Markdent::Role::BalancedEvent::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use List::AllUtils qw( all );
 use Markdent::Types qw( ArrayRef Str );
 use MooseX::Params::Validate qw( pos_validated_list );
@@ -41,7 +42,9 @@ role {
 
 1;
 
-__END__
+# ABSTRACT: A parameterized role for events which can check if they match balance another event
+
+
 
 =pod
 
@@ -49,6 +52,10 @@ __END__
 
 Markdent::Role::BalancedEvent - A parameterized role for events which can check if they match balance another event
 
+=head1 VERSION
+
+version 0.10
+
 =head1 DESCRIPTION
 
 This role provides behavior for start and end events which can be checked for
@@ -84,13 +91,17 @@ See L<Markdent> for bug reporting details.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
