@@ -1,10 +1,11 @@
 package Markdent::Role::Event;
+BEGIN {
+  $Markdent::Role::Event::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use namespace::autoclean;
 use MooseX::Role::Parameterized;
 
@@ -141,7 +142,9 @@ sub _debug_value {
 
 1;
 
-__END__
+# ABSTRACT: Implements behavior shared by all events
+
+
 
 =pod
 
@@ -149,6 +152,10 @@ __END__
 
 Markdent::Role::Event - Implements behavior shared by all events
 
+=head1 VERSION
+
+version 0.10
+
 =head1 DESCRIPTION
 
 This role provides shared behavior for all event classes. It is actually
@@ -188,13 +195,17 @@ See L<Markdent> for bug reporting details.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
