@@ -1,10 +1,11 @@
 package Markdent::Role::EventAsText;
+BEGIN {
+  $Markdent::Role::EventAsText::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use namespace::autoclean;
 use Moose::Role;
 
@@ -12,7 +13,9 @@ requires 'as_text';
 
 1;
 
-__END__
+# ABSTRACT: Indicates that an event has an as_text method
+
+
 
 =pod
 
@@ -20,6 +23,10 @@ __END__
 
 Markdent::Role::EventAsText - Indicates that an event has an as_text method
 
+=head1 VERSION
+
+version 0.10
+
 =head1 DESCRIPTION
 
 An event with an as_text method will do this role.
@@ -38,13 +45,17 @@ See L<Markdent> for bug reporting details.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
