@@ -1,10 +1,11 @@
 package Markdent::Role::EventsAsMethods;
+BEGIN {
+  $Markdent::Role::EventsAsMethods::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use Scalar::Util qw( blessed );
 
 use namespace::autoclean;
@@ -23,13 +24,19 @@ sub handle_event {
 
 1;
 
-__END__
+# ABSTRACT: Turns events into method calls
+
+
 
 =pod
 
 =head1 NAME
 
-Markdent::Role::DebugPrinter - Turns events into method calls
+Markdent::Role::EventsAsMethods - Turns events into method calls
+
+=head1 VERSION
+
+version 0.10
 
 =head1 DESCRIPTION
 
@@ -69,13 +76,17 @@ See L<Markdent> for bug reporting details.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
