@@ -1,10 +1,11 @@
 package Markdent::Role::FilterHandler;
+BEGIN {
+  $Markdent::Role::FilterHandler::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
-
 use namespace::autoclean;
 use Moose::Role;
 
@@ -30,7 +31,9 @@ sub handle_event {
 
 1;
 
-__END__
+# ABSTRACT: A role for handlers which act as filters
+
+
 
 =pod
 
@@ -38,6 +41,10 @@ __END__
 
 Markdent::Role::FilterHandler - A role for handlers which act as filters
 
+=head1 VERSION
+
+version 0.10
+
 =head1 DESCRIPTION
 
 This role implements behavior and interface for filtering handlers. A filter
@@ -75,13 +82,17 @@ See L<Markdent> for bug reporting details.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
